@@ -24,20 +24,22 @@
 #define FILTERTOOLFACTORY_H
 
 // lib
-#include <kasten/okteta/oktetakastencontrollers_export.h>
+#include "oktetakastencontrollers_export.h"
 // Kasten core
-#include <kasten/abstracttoolfactory.h>
+#include <abstracttoolfactory.h>
 
-namespace Kasten {
+
+namespace Kasten
+{
 
 class OKTETAKASTENCONTROLLERS_EXPORT FilterToolFactory : public AbstractToolFactory
 {
-public:
+  public:
     FilterToolFactory();
-    ~FilterToolFactory() override;
+    virtual ~FilterToolFactory();
 
-public: // AbstractToolFactory API
-    AbstractTool* create() override;
+  public: // AbstractToolFactory API
+    virtual AbstractTool* create();
 };
 
 }
