@@ -31,10 +31,10 @@
 class KXMLGUIClient;
 class KSelectAction;
 class KToggleAction;
-class KAction;
+class QAction;
 
 
-namespace Kasten2
+namespace Kasten
 {
 
 class ByteArrayView;
@@ -76,8 +76,8 @@ class OKTETAKASTENCONTROLLERS_EXPORT ViewConfigController : public AbstractXmlGu
     KSelectAction* mCodingAction;
     KSelectAction* mEncodingAction;
     KToggleAction* mShowsNonprintingAction;
-    KAction* mSetBytesPerLineAction;
-    KAction* mSetBytesPerGroupAction;
+    QAction* mSetBytesPerLineAction;
+    QAction* mSetBytesPerGroupAction;
     KSelectAction* mResizeStyleAction;
     KToggleAction* mShowOffsetColumnAction;
     KSelectAction* mOffsetCodingAction;
